pub struct Limit<R> { /* private fields */ }Expand description
Limit
This struct can be used for limiting data read from some source.
Implementations
Sourceimpl<R> Limit<R>
impl<R> Limit<R>
Sourcepub async fn read_to_end(&mut self, capacity: Option<usize>) -> Result<Vec<u8>>
Available on crate feature async-std only.
pub async fn read_to_end(&mut self, capacity: Option<usize>) -> Result<Vec<u8>>
async-std only.Reads all bytes
Be careful using this function (in case your source produces a lot of data).
Sourceimpl Limit<File>
impl Limit<File>